@@ -12,8 +12,9 @@ logger = logging.getLogger(__name__)
 base_path: str = os.path.abspath(os.path.dirname(__file__))
 
 input_path: str = os.path.abspath(os.path.join(base_path, "input/"))
-output_path: str = os.path.abspath(os.path.join(base_path, "output/"))
-expected_path: str = os.path.abspath(os.path.join(base_path, "expected/"))
+output_base_path: str = os.path.abspath(os.path.join(base_path, "output/"))
+expected_base_path: str = os.path.abspath(os.path.join(base_path, "expected/"))
+
 
 
 try:
@@ -39,16 +40,22 @@ def color_diff(diff):
         else:
             yield line
 
+def test_minify_regressions():
+    return regressions_work("minify")
 
-def clear_output():
-    shutil.rmtree(output_path, ignore_errors=True)
+def test_beautify_regressions():
+    return regressions_work("beautify")
 
-
-def test_regressions():
+def regressions_work(mode):
+    output_path = os.path.join(output_base_path, mode)
+    expected_path = os.path.join(expected_base_path, mode)
+    expected_files = generate_file_list(expected_path)
+    def clear_output():
+        shutil.rmtree(output_path, ignore_errors=True)
     # 1. Clear old result if any
-    clear_output()
+    #clear_output()
     # 2. Run tool on input
-    settings = {"input": input_path, "output": output_path, "verbose": False}
+    settings = {"mode": mode, "input": input_path, "output": output_path, "verbose": False}
     processor = web_minify.processor.Processor(settings)
     res, msg = processor.sanity_checks()
     if not res:
@@ -56,7 +63,6 @@ def test_regressions():
     assert res
     processor.process_files()
     # 3. Compare output with expected
-    expected_files = generate_file_list(expected_path)
     # output_files = generate_file_list(output_path)
     # logger.warning(pprint.pformat(expected_files))
     # logger.warning(pprint.pformat(output_files))
@@ -87,4 +93,4 @@ def test_regressions():
     assert errors == 0
 
     # 4. Clear result
-    clear_output()
+    #clear_output()
