@@ -2,5 +2,5 @@
 
 from web_minify.minify import main
 
-if __name__ in '__main__':
+if __name__ in "__main__":
     main()
