@@ -2,7 +2,7 @@ import os
 import pprint
 import datetime
 import time
-from .handlers import html_minify, css_minify, js_minify, sass_minify, png_minify, jpeg_minify, svg_minify
+import importlib
 from .files import path_is_in_path, generate_file_list, determine_file_extension
 from .time import human_delta
 import logging
@@ -22,20 +22,19 @@ class Processor:
         self.output_is_dir = self.output and os.path.isdir(self.output)
         self.output_exists = self.output and os.path.exists(self.output)
 
+        self.mode: bool = settings.get("mode", "minify")
+        self.format: bool = settings.get("format", False)
         self.overwrite: bool = settings.get("overwrite", False)
         self.on_change: bool = settings.get("on_change", False)
-        self.format: bool = settings.get("format", False)
         self.prefix: bool = settings.get("prefix", False)
         self.zipy: bool = settings.get("zipy", False)
         self.hash: bool = settings.get("hash", False)
         self.verbose: bool = settings.get("verbose", False)
         self.force: bool = settings.get("force", False)
 
-        # fmt off
-        self.processor_map = {"sass": (sass_minify, False), "css": (css_minify, False), "html": (html_minify, False), "svg": (svg_minify, False), "js": (js_minify, False), "json": (js_minify, False), "png": (png_minify, True), "jpeg": (jpeg_minify, True)}
-        # fmt on
+        self.prepare_handlers()
 
-        self.valid_extensions = [f".{ext}" for ext in self.processor_map.keys()]
+        self.valid_extensions = [f".{ext}" for ext in self.handlers.keys()]
         if self.verbose:
             logger.info("### Settings:")
             logger.info(pprint.pformat(self.settings))
@@ -44,6 +43,9 @@ class Processor:
         self.pool = None
 
     def sanity_checks(self):
+        valid_modes = ["minify", "beautify"]
+        if not self.mode in valid_modes:
+            return (False, f"The specified mode {mode} was not valid. NOTE: Valid modes are {pprint.pformat(valid_modes)}")
         if not self.input or not self.input_exists:
             return (False, f"The input specified '{self.input}' did not exist. Input must be an existing directory or file")
         if not self.overwrite and self.on_change:
@@ -56,6 +58,22 @@ class Processor:
             return (False, f"The input '{self.input}' is a subpath of output '{self.output}'")
         return True, None
 
+    def prepare_handlers(self):
+        self.handlers={}
+        handlers_mod = importlib.import_module('.handlers', 'web_minify')
+        for name, cls in handlers_mod.__dict__.items():
+            if isinstance(cls, type):
+                handler = cls(self.settings)
+                if not handler:
+                    logger.warning(f"Could not instanciate handler '{name}', skipping...")
+                    continue
+                for extension in handler.extensions():
+                    # logger.warning(f"Configuring handler {name} for .{extension}")
+                    self.handlers[extension] = handler
+
+    def get_handler(self, extension):
+        return self.handlers.get(extension, None)
+
     def process_file(self, input_path: str, output_path: str):
         if self.verbose:
             logger.info(f"Processing '{input_path}' to '{output_path}'")
@@ -89,12 +107,13 @@ class Processor:
                 vip_file = True
             else:
                 return False, False, False, f"Unknown extension '{raw_extension}' for input file"
-        processor = None
+        handler = None
         is_binary = True
         if not vip_file:
-            processor, is_binary = self.processor_map.get(extension, None)
-            if not processor:
-                return False, False, False, "Could not find processor for input file"
+            handler = self.get_handler(extension)
+            if not handler:
+                return False, False, False, f"Could not find handler for input file with extension {extension}"
+            is_binary = handler.is_binary()
         original_content = None
         try:
             with open(input_path, "rb") if is_binary else open(input_path, "r", encoding="utf-8") as file:
@@ -104,9 +123,9 @@ class Processor:
         if not original_content:
             logger.warning(f"Input file '{input_path}' was empty")
         processed_content = None
-        processor_errors = None
+        handler_errors = None
         was_copied = False
-        do_copy = vip_file or (extension in ["js", "css", "sass", "html", "svg", "png", "jpeg"] and self.settings.get(f"disable_{extension}", False))
+        do_copy = handler is None or vip_file or (extension in ["js", "css", "sass", "html", "svg", "png", "jpeg"] and self.settings.get(f"disable_{extension}", False))
         if do_copy:
             # Perform copy
             # logger.info(f"SUPPOSED TO COPY: {input_path} ({extension})")
@@ -114,11 +133,13 @@ class Processor:
             was_copied = True
         else:
             # logger.info(f"SUPPOSED TO PROCESS: {input_path} ({extension})")
-            _processed_content, processor_errors = processor(original_content, self.settings)
+            tup=handler.process(original_content)
+            logger.info(f"TUP: ({tup}) with {handler.extensions()}")
+            _processed_content, handler_errors = tup
             processed_content = _processed_content
         # logger.info(f"Content of file {input_path} was of type {type(original_content)} while processed {type(processed_content)}")
-        if processor_errors:
-            return False, False, False, ", ".join(processor_errors)
+        if handler_errors:
+            return False, False, False, ", ".join(handler_errors)
         if None == processed_content:
             logger.warning(f"Processed file '{input_path}' was empty")
         try:
